AIAnalyzer class

Constructors

AIAnalyzer({String? openAiKey})

Properties

hashCode int
The hash code for this object.
no setterinherited
openAiKey String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

analyzePage(String htmlContent, String url) Future<AIReport>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited