SimpleStateBridge<T> class

A concrete implementation of StateBridge backed by a ValueNotifier.

Inheritance

Constructors

SimpleStateBridge(T initialState)
Creates a SimpleStateBridge with the given initialState.

Properties

hashCode int
The hash code for this object.
no setterinherited
notifier ValueNotifier<T>
The underlying ValueNotifier exposing state changes.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state → T
The current state value.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(T newState) → void
Updates the state and triggers change notification.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited