StateBridge<T> class abstract

Abstract interface for state management with change notification.

Implementers

Constructors

StateBridge()

Properties

hashCode int
The hash code for this object.
no setterinherited
notifier ValueNotifier<T>
The value notifier that exposes state changes to listeners.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state → T
The current state value.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(T newState) → void
Updates the current state to newState and notifies listeners.

Operators

operator ==(Object other) bool
The equality operator.
inherited