notifier property
ValueNotifier<T>
get
notifier
The value notifier that exposes state changes to listeners.
Implementation
ValueNotifier<T> get notifier;
The value notifier that exposes state changes to listeners.
ValueNotifier<T> get notifier;