build method
Builds the widget tree by delegating to builder with the current device type.
Implementation
@override
Widget build(BuildContext context) {
return builder(context, DeviceDetector.type);
}
Builds the widget tree by delegating to builder with the current device type.
@override
Widget build(BuildContext context) {
return builder(context, DeviceDetector.type);
}