LazyLoader class
Utilities for lazy-loading widgets and async data.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lazyWidget(
Future< Widget> builder(), {Widget? placeholder}) → Widget -
Returns a FutureBuilder that shows
placeholderwhilebuilderresolves. -
loadAsync<
T> (Future< T> loader(), {Duration delay = Duration.zero}) → Future<T> -
Executes
loaderafter an optionaldelay.