OptimizedImage class

Inheritance

Constructors

OptimizedImage({Key? key, String? assetPath, String? networkUrl, String? filePath, Uint8List? bytes, double? width, double? height, BoxFit fit = BoxFit.cover, int? maxWidth, int? maxHeight, Widget? placeholder, Widget? errorWidget, Map<String, String>? httpHeaders})
const
OptimizedImage.asset(String path, {Key? key, double? width, double? height, BoxFit fit = BoxFit.cover, int? maxWidth, int? maxHeight, Widget? placeholder, Widget? errorWidget})
factory
OptimizedImage.file(String path, {Key? key, double? width, double? height, BoxFit fit = BoxFit.cover, int? maxWidth, int? maxHeight, Widget? placeholder, Widget? errorWidget})
factory
OptimizedImage.memory(Uint8List bytes, {Key? key, double? width, double? height, BoxFit fit = BoxFit.cover, int? maxWidth, int? maxHeight, Widget? placeholder, Widget? errorWidget})
factory
OptimizedImage.network(String url, {Key? key, double? width, double? height, BoxFit fit = BoxFit.cover, int? maxWidth, int? maxHeight, Widget? placeholder, Widget? errorWidget, Map<String, String>? httpHeaders})
factory

Properties

assetPath String?
final
bytes Uint8List?
final
errorWidget Widget?
final
filePath String?
final
fit BoxFit
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
httpHeaders Map<String, String>?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxHeight int?
final
maxWidth int?
final
networkUrl String?
final
placeholder Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited