PluginFallback class

Provides safe fallback between web and native implementations.

Constructors

PluginFallback()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

safeCall<T>({required T webImplementation(), required T fallback()}) → T
Runs webImplementation on web, otherwise runs fallback.