PrerenderCli class

CLI utility for pre-rendering static routes for SEO.

Constructors

PrerenderCli()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

prerenderRoutes(List<String> routes, String baseUrl, String outputDir) Future<void>
Pre-renders the given routes from baseUrl into outputDir.