isAuthenticated static method
Returns whether the user is authenticated for the given route.
Implementation
static Future<bool> isAuthenticated(BuildContext context, String route) async {
return _isAuthenticated;
}
Returns whether the user is authenticated for the given route.
static Future<bool> isAuthenticated(BuildContext context, String route) async {
return _isAuthenticated;
}