RouterMiddleware class

Static registry for route guards and middleware processors.

Constructors

RouterMiddleware()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

guards List<RouteGuard>
Registered route guards.
getter/setter pair
preProcessors List<Middleware>
Registered pre-processing middleware.
getter/setter pair

Static Methods

addGuard(RouteGuard guard) → void
Registers a new route guard.
addMiddleware(Middleware middleware) → void
Registers a new pre-processing middleware.