SmartRouter class
Central router that manages navigation and route matching.
Constructors
-
SmartRouter({required Map<
String, WidgetBuilder> routes, required SFWFConfig config, List<RouteDefinition> routeDefinitions = const [], WidgetBuilder? notFoundBuilder, Map<String, RouteTransitionsBuilder> ? customTransitions}) - Creates a SmartRouter and initializes its delegate and parser.
Properties
- backDispatcher ↔ BackButtonDispatcher
-
The back button dispatcher.
latefinal
- config → SFWFConfig
-
The application configuration.
final
-
customTransitions
→ Map<
String, RouteTransitionsBuilder> ? -
Custom page transition builders keyed by route name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- notFoundBuilder → WidgetBuilder?
-
Optional builder for the 404 not-found page.
final
-
routeDefinitions
→ List<
RouteDefinition> -
Route definitions with parameterized patterns.
final
-
routeParser
↔ RouteInformationParser<
RoutePath> -
The route information parser.
latefinal
-
routerDelegate
↔ RouterDelegate<
RoutePath> -
The router delegate used by MaterialApp.router.
latefinal
-
routes
→ Map<
String, WidgetBuilder> -
A map of named route builders.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited