SeoData class

Constructors

SeoData({String? title, String? description, String? image, Map<String, dynamic>? structuredData})
const

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
image String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structuredData Map<String, dynamic>?
final
title String?
final

Methods

merge(SeoData other) SeoData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited