SFWFConfig class

Constructors

SFWFConfig({required String appName, required String baseUrl, SeoDefaults seoDefaults = const SeoDefaults(), SsrMode ssrMode = SsrMode.hybrid, bool enableAI = false, String? openAiApiKey, List<Locale> supportedLocales = const [Locale('en')], Duration cacheDuration = const Duration(minutes: 5)})
const

Properties

appName String
final
baseUrl String
final
cacheDuration Duration
final
enableAI bool
final
hashCode int
The hash code for this object.
no setterinherited
openAiApiKey String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seoDefaults SeoDefaults
final
ssrMode SsrMode
final
supportedLocales List<Locale>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited