SeoDefaults class

Default SEO metadata values for the application.

Constructors

SeoDefaults({String titleSuffix = ' | SFWF', String defaultDescription = 'Built with Smart Flutter Web Framework', String defaultImage = '/default-og.png', String twitterHandle = '@sfwf'})
Creates a new SeoDefaults with the given values.
const

Properties

defaultDescription String
Default meta description for pages.
final
defaultImage String
Default Open Graph image URL.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleSuffix String
Suffix appended to the page title.
final
twitterHandle String
Default Twitter handle for SEO.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited