SeoDefaults class

Constructors

SeoDefaults({String titleSuffix = ' | SFWF', String defaultDescription = 'Built with Smart Flutter Web Framework -超越 JS/TS', String defaultImage = '/default-og.png', String twitterHandle = '@sfwf'})
const

Properties

defaultDescription String
final
defaultImage String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleSuffix String
final
twitterHandle String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited