CacheEntry class
A cache entry holding a value and its expiration time.
Constructors
- CacheEntry(dynamic value, DateTime expiry)
-
Creates a CacheEntry with the given
valueandexpiry. -
CacheEntry.fromJson(Map<
String, dynamic> json) -
Creates a CacheEntry from a JSON map.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes this entry to a JSON-compatible map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited