RouteDefinition class
Defines a route pattern with an optional name and metadata.
Constructors
-
RouteDefinition({required String path, String? name, Map<
String, dynamic> ? meta}) -
Creates a RouteDefinition with the required path.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
meta
→ Map<
String, dynamic> ? -
Optional metadata associated with the route.
final
- name → String?
-
An optional name for the route.
final
- path → String
-
The route path pattern (may contain
:paramsegments).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited