RouteMatch class
Holds the result of a successful route pattern match.
Constructors
-
RouteMatch(String name, {String? originalPath, Map<
String, String> params = const {}}) -
Creates a RouteMatch with the matched name and optional parameters.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The matched route name.
final
- originalPath → String?
-
The original path that was matched.
final
-
params
→ Map<
String, String> -
Parameters extracted from the matched route pattern.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited