RoutePath class

Represents a parsed route with path, parameters, and query parameters.

Constructors

RoutePath(String path, {Map<String, String> params = const {}, Map<String, String> queryParams = const {}})
Creates a RoutePath with the given path and optional parameters.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
params Map<String, String>
Path parameters extracted from the route pattern.
final
path String
The route path string.
final
queryParams Map<String, String>
Query parameters from the URL.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? path, Map<String, String>? params, Map<String, String>? queryParams}) RoutePath
Creates a copy of this RoutePath with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns a string representation of this route path.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited