SmartRouter class
Constructors
-
SmartRouter({required Map<
String, WidgetBuilder> routes, required SFWFConfig config})
Properties
- backDispatcher ↔ BackButtonDispatcher
-
latefinal
- config → SFWFConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
routeParser
↔ RouteInformationParser<
RoutePath> -
latefinal
-
routerDelegate
↔ RouterDelegate<
RoutePath> -
latefinal
-
routes
→ Map<
String, WidgetBuilder> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited