SeoData class

Constructors

SeoData({String? title, String? description, String? image, String? ogType, String? twitterCard, String? keywords, String? themeColor, String? canonicalUrl, String? locale, bool? noIndex, Map<String, dynamic>? structuredData})
const

Properties

canonicalUrl String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
image String?
final
keywords String?
final
locale String?
final
noIndex bool?
final
ogType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structuredData Map<String, dynamic>?
final
themeColor String?
final
title String?
final
twitterCard String?
final

Methods

merge(SeoData other) SeoData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited